@@ -21,7 +21,7 @@ import youtube_dl as youtube_yl  # youtube yownloader
 import ffmpeg
 
 
-__version__ = '0.9.5'
+__version__ = '0.9.6'
 
 
 # TODO: ensure videos are concatenated in the order they're given
@@ -33,9 +33,6 @@ __version__ = '0.9.5'
 # TODO: function to get list of videos from option like youtube channel, maybe with time conditions
 
 
-YOUTUBE_DL_DEFAULT_OUTTMPL = '%(title)s-%(id)s.%(ext)s'
-
-
 # command line interface
 parser = argparse.ArgumentParser(description='Script for automatically downloading a list of videos, speeding them up, '
                                              'and concatenating them.',
@@ -150,7 +147,7 @@ def download_and_speed_up(vods_list, out_folder=args.out_folder, prefer_best_qua
     """
     ydl_args = {
         # 'quiet': not args.verbose,
-        'outtmpl': f'/{out_folder}/originals/{YOUTUBE_DL_DEFAULT_OUTTMPL}',
+        'outtmpl': f'/{out_folder}/originals/{youtube_yl.DEFAULT_OUTTMPL}',
         'progress_hooks': [speed_up],
     }
     if not prefer_best_quality:
@@ -181,7 +178,9 @@ def speed_up(video_download, speed=args.speed):
     # filename_no_extension = video_download['filename'][:-len(file_extension)]
     filename = Path(video_download['filename'])
     out_name = filename.with_stem(filename.stem.replace("'", '') + f'-{speed}x').name
-    out_filename = filename.parents[1] / 'speedup' / out_name
+    speedup_folder = filename.parents[1] / 'speedup'
+    speedup_folder.mkdir(exist_ok=True)
+    out_filename = speedup_folder / out_name
 
     stream = ffmpeg.input(str(filename))
     stream = ffmpeg.setpts(stream, f'(1/{speed})*PTS')
